autowisp.data_reduction.source_extracted_psf_map module — AutoWISP documentation

# autowisp.data_reduction.source_extracted_psf_map module

## Class Inheritance Diagram

Define callable class representing PSF maps from source extraction.

class autowisp.data_reduction.source_extracted_psf_map.SourceExtractedPSFMap(psf_parameters, terms_expression, coefficients)

  Bases: `object`

  Evaluate smoothed PSF maps based on sorce extraction.

  __call__(source_data)

    Evaluate the map for the given sources.

    Parameters:

      source_data (numpy structured array or pandas DataFrame) – The x, y and catalogue information for the sources for which to evaluate the map. The names of the fields should exactly match the names used when creating the map.

    Returns:

      The PSF parameters predicted by the map for the input sources. The fields will have the names of the PSF parameters.

    Return type:

      numpy structured array

  __init__(psf_parameters, terms_expression, coefficients)

    Create the map for the given parameters per the given coefficients.

    Parameters:

      - psf_parameters ([str]) – The names of the mapped PSF parameters.

      - terms_expression (str) – An expression that expands to the fitting terms the map depends on.

      - coefficients (2-D numpy.array) – The coefficients defining the map. The outer (0-th) index should select the PSF parameter.

    Returns:

      None